/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2013 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Application
    cavitatingFoam

Description
    Transient cavitation code based on the homogeneous equilibrium model
    from which the compressibility of the liquid/vapour "mixture" is obtained.

    Turbulence modelling is generic, i.e. laminar, RAS or LES may be selected.

\*---------------------------------------------------------------------------*/

#include "fvCFD.H"
#include "CMULES.H" //new added
#include "subCycle.H"//new added
#include "interfaceProperties.H"// new added
#include "phaseChangeTwoPhaseMixture.H"//new added
//#include "barotropicCompressibilityModel.H"
//#include "incompressibleTwoPhaseMixture.H"
#include "turbulenceModel.H"
#include "pimpleControl.H"
#include "fvIOoptionList.H"//new added
#include "fixedFluxPressureFvPatchScalarField.H"//new added

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

int main(int argc, char *argv[])
{
    #include "setRootCase.H"
    #include "createTime.H"
    #include "createMesh.H"
    #include "readGravitationalAcceleration.H"//new added
   // #include "readThermodynamicProperties.H"
   // #include "readControls.H" bunu cikart
   #include "initContinuityErrs.H" 
   #include "createFields.H"
    
   // #include "compressibleCourantNo.H"
    
    #include "readTimeControls.H"//new added
    
    pimpleControl pimple(mesh);

   #include "createPrghCorrTypes.H"
    #include "correctPhi.H"
   #include "CourantNo.H"
   #include "setInitialDeltaT.H" 

    // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

    Info<< "\nStarting time loop\n" << endl;

    while (runTime.run())
    {
        #include "readTimeControls.H"
        #include "CourantNo.H"
        #include "setDeltaT.H"

        runTime++;

        Info<< "Time = " << runTime.timeName() << nl << endl;

        // --- Pressure-velocity PIMPLE corrector loop
        while (pimple.loop())
       
       // additional part 1
       {
            #include "alphaControls.H"

            surfaceScalarField rhoPhi
            (
                IOobject
                (
                    "rhoPhi",
                    runTime.timeName(),
                    mesh
                ),
                mesh,
                dimensionedScalar("0", dimMass/dimTime, 0)
            );

            if (pimple.firstIter() || alphaOuterCorrectors)
            {
                twoPhaseProperties->correct();

                #include "alphaEqnSubCycle.H"
                interface.correct();
            }

            #include "UEqn.H"
     
   /* {
            #include "rhoEqn.H"
            #include "alphavPsi.H"
            #include "UEqn.H"*/

            // --- Pressure corrector loop
            while (pimple.correct())
            {
                #include "pEqn.H"
            }

            if (pimple.turbCorr())
            {
                turbulence->correct();
            }
        }

        runTime.write();

        Info<< "ExecutionTime = " << runTime.elapsedCpuTime() << " s"
            << "  ClockTime = " << runTime.elapsedClockTime() << " s"
            << nl << endl;
        
        //To watch the output date on screen
        Info<< "Max pressure = " << max(p).value() << endl;
        Info<< "Min pressure = " << min(p).value() << endl;
        Info<< "Max velocity = " << max(mag(U)).value() << endl <<endl;
   
       
    }

    Info<< "End\n" << endl;

    return 0;
}


// ************************************************************************* //
